..
    This file is part of Invenio.
    Copyright (C) 2014, 2015 CERN.

    Invenio is free software; you can redistribute it
    and/or modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.

    Invenio is distributed in the hope that it will be
    useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Invenio; if not, write to the
    Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
    MA 02111-1307, USA.

    In applying this license, CERN does not
    waive the privileges and immunities granted to it by virtue of its status
    as an Intergovernmental Organization or submit itself to any jurisdiction.

.. _module_oauthclient:

=====================
 Invenio-OAuthClient
=====================

.. automodule:: invenio_oauthclient

Contents
========

.. toctree::
   :maxdepth: 2

.. _module_oauthclient_conf:

Configuration
=============

.. automodule:: invenio_oauthclient.config

Contrib
=======

GitHub
------
.. automodule:: invenio_oauthclient.contrib.github

ORCID
-----
.. automodule:: invenio_oauthclient.contrib.orcid

CERN
----
.. automodule:: invenio_oauthclient.contrib.cern

API
===

Handlers
--------

.. automodule:: invenio_oauthclient.handlers
   :members:

Models
------

.. automodule:: invenio_oauthclient.models
   :members:

Views
-----

.. automodule:: invenio_oauthclient.views.client
   :members:

.. automodule:: invenio_oauthclient.views.settings
   :members:

Forms
-----

.. automodule:: invenio_oauthclient.forms
   :members:

Utils
-----

.. automodule:: invenio_oauthclient.utils
   :members:

Registries
----------

.. automodule:: invenio_oauthclient.client
   :members:

Errors
------

.. automodule:: invenio_oauthclient.errors
   :members:

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
